@@ -68,7 +68,7 @@ static HildonIMUI *client = NULL;
 static GtkWidget *window = NULL, *label = NULL;
 static GtkWidget* buttons[5];
 static gint candword_index = 2;
-static gboolean bquotedbl = TRUE, bquotright = TRUE, bparen = TRUE;
+static gboolean chinese_mode = FALSE, bquotedbl = TRUE, bquotright = TRUE, bparen = TRUE;
 
 static GType hildon_im_keyboard_decorator_type = 0;
 static GtkWidgetClass *parent_class = NULL;
@@ -498,7 +498,12 @@ gboolean fake_key_press(guint keyval, guint state, gchar **str, gboolean *ret)
 {
   *str = NULL;
   *ret = FALSE;
-  if(hildon_im_ui_get_shift_locked(client) || hildon_im_ui_get_level_locked(client))
+  if(keyval == ' ' && state == 4){
+    chinese_mode = !chinese_mode;
+    *ret = TRUE;
+    return TRUE;
+  }
+  if(!chinese_mode || hildon_im_ui_get_shift_locked(client) || hildon_im_ui_get_level_locked(client))
     return TRUE;
   if(((keyval >= 'a' && keyval <= 'z') || ((keyval == ',' || keyval == '.') && iPYInsertPoint)) && state == 0){
       DoPYInput(keyval);
